=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2009-04-09 20:04:47 +0000
+++ bzrlib/tests/test_http.py	2009-04-11 15:39:28 +0000
@@ -215,9 +215,11 @@
 
 class TestAuthHeader(tests.TestCase):
 
-    def parse_header(self, header):
-        ah =  _urllib2_wrappers.AbstractAuthHandler()
-        return ah._parse_auth_header(header)
+    def parse_header(self, header, auth_handler_class=None):
+        if auth_handler_class is None:
+            auth_handler_class = _urllib2_wrappers.AbstractAuthHandler
+        self.auth_handler =  auth_handler_class()
+        return self.auth_handler._parse_auth_header(header)
 
     def test_empty_header(self):
         scheme, remainder = self.parse_header('')
@@ -235,6 +237,14 @@
         self.assertEquals('basic', scheme)
         self.assertEquals('realm="Thou should not pass"', remainder)
 
+    def test_basic_extract_realm(self):
+        scheme, remainder = self.parse_header(
+            'Basic realm="Thou should not pass"',
+            _urllib2_wrappers.BasicAuthHandler)
+        match, realm = self.auth_handler.extract_realm(remainder)
+        self.assertTrue(match is not None)
+        self.assertEquals('Thou should not pass', realm)
+
     def test_digest_header(self):
         scheme, remainder = self.parse_header(
             'Digest realm="Thou should not pass"')
@@ -1533,7 +1543,7 @@
         self.assertEquals(expected_prompt, stdout.read(len(expected_prompt)))
         self._check_password_prompt(t._unqualified_scheme, 'joe',
                                     stdout.readline())
- 
+
     def test_prompt_for_password(self):
         if self._testing_pycurl():
             raise tests.TestNotApplicable(

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2009-04-09 20:04:47 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2009-04-11 06:32:41 +0000
@@ -1244,14 +1244,20 @@
         auth_header = 'Basic ' + raw.encode('base64').strip()
         return auth_header
 
+    def extract_realm(self, header_value):
+        match = self.auth_regexp.search(header_value)
+        realm = None
+        if match:
+            realm = match.group(1)
+        return match, realm
+
     def auth_match(self, header, auth):
         scheme, raw_auth = self._parse_auth_header(header)
         if scheme != 'basic':
             return False
 
-        match = self.auth_regexp.search(raw_auth)
+        match, realm = self.extract_realm(raw_auth)
         if match:
-            realm = match.groups()
             if scheme != 'basic':
                 return False
 

